/* 
 * Copyright 1994 Alastair Gourlay
 *
 * Permission to use, copy, modify, and distribute this software and its
 * documentation for any purpose and without fee is hereby granted, provided 
 * that the above copyright notice appear in all copies and that both that 
 * copyright notice and this permission notice appear in supporting 
 * documentation.
 */

/*
 *
 * CaptionP.h - XmpCaption Private header
 *
 */

#ifndef _XmpCaptionP_h
#define _XmpCaptionP_h

#include <Xm/RepType.h>
#include "GeometryP.h"
#include "Caption.h"

typedef struct
{
	XmRepTypeId		caption_justify_id;
	XmRepTypeId		caption_alignment_id;
	XtPointer		extension;
} XmpCaptionClassPart;

typedef struct _XmpCaptionClassRec
{
	CoreClassPart		core_class;
	CompositeClassPart	composite_class;
	ConstraintClassPart	constraint_class;
	XmManagerClassPart	manager_class;
	XmpGeometryClassPart	geometry_class;
	XmpCaptionClassPart	caption_class;
} XmpCaptionClassRec;

externalref XmpCaptionClassRec xmpCaptionClassRec;

typedef struct
{
	Boolean			strech_control;

	Dimension		margin_width;
	Dimension		margin_height;
	Dimension		horizontal_spacing;
	Dimension		vertical_spacing;

	Dimension		maximum_caption_width;
	Dimension		true_minimum_height;
	Dimension		minimum_useful_height;
	Dimension		total_stretch_pref_height;
} XmpCaptionPart, *XmpCaptionPartPtr;

typedef struct _XmpCaptionRec
{
	CorePart		core;
	CompositePart		composite;
	ConstraintPart		constraint;
	XmManagerPart		manager;
	XmpGeometryPart		geometry;
	XmpCaptionPart		caption;
} XmpCaptionRec;

typedef struct _XmpCaptionConstraintPart
{
	unsigned char		caption_justify;
	unsigned char		caption_alignment;
	Boolean			stretch_horizontal;
	Boolean			stretch_vertical;
} XmpCaptionConstraintPart, *XmpCaptionConstraintPartPtr;

typedef struct _XmpCaptionConstraintRec
{
	XmManagerConstraintPart		manager;
	XmpGeometryConstraintPart	geometry;
	XmpCaptionConstraintPart	caption;
} XmpCaptionConstraintRec, *XmpCaptionConstraint;


/* Instance field access macros */

#define MarginWidth(w) (w->caption.margin_width)
#define MarginHeight(w) (w->caption.margin_height)
#define HorizontalSpacing(w) (w->caption.horizontal_spacing)
#define VerticalSpacing(w) (w->caption.vertical_spacing)
#define MaximumCaptionWidth(w) (w->caption.maximum_caption_width)
#define TrueMinimumHeight(w) (w->caption.true_minimum_height)
#define MinimumUsefulHeight(w) (w->caption.minimum_useful_height)
#define TotalStretchPrefHeight(w) (w->caption.total_stretch_pref_height)
#define StrechControl(w) (w->caption.strech_control)

/* Constraint field access macros */

#define CaptionConstraint(w) ((XmpCaptionConstraint)(w->core.constraints))

#define CaptionAlignment(w) (CaptionConstraint(w)->caption.caption_alignment)
#define CaptionJustify(w) (CaptionConstraint(w)->caption.caption_justify)
#define StretchHorizontal(w) (CaptionConstraint(w)->caption.stretch_horizontal)
#define StretchVertical(w) (CaptionConstraint(w)->caption.stretch_vertical)

/* Class field access macros */

#define CaptionAlignmentId (xmpCaptionClassRec.caption_class.caption_alignment_id)
#define CaptionJustifyId (xmpCaptionClassRec.caption_class.caption_justify_id)

#endif /* _XmpCaptionP_h */
